==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/RFQSUPPLIERDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.AMOUNT;


/**
 * <p>Classe Java pour RFQSUPPLIERDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RFQSUPPLIERDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LANGUAGEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LEADTIMES" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQSUPPLIERDETAILS_Type", propOrder = {
    "languageid",
    "leadtimes"
})
public class RFQSUPPLIERDETAILS_Type {

    @XmlElement(name = "LANGUAGEID", required = true)
    protected LANGUAGEID_Type languageid;
    @XmlElement(name = "LEADTIMES")
    protected AMOUNT leadtimes;

    /**
     * Obtient la valeur de la propriété languageid.
     * 
     * @return
     *     possible object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public LANGUAGEID_Type getLANGUAGEID() {
        return languageid;
    }

    /**
     * Définit la valeur de la propriété languageid.
     * 
     * @param value
     *     allowed object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public void setLANGUAGEID(LANGUAGEID_Type value) {
        this.languageid = value;
    }

    /**
     * Obtient la valeur de la propriété leadtimes.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getLEADTIMES() {
        return leadtimes;
    }

    /**
     * Définit la valeur de la propriété leadtimes.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setLEADTIMES(AMOUNT value) {
        this.leadtimes = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/RFQSUPPLIERDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.AMOUNT;


/**
 * <p>Java class for RFQSUPPLIERDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RFQSUPPLIERDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LANGUAGEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LEADTIMES" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQSUPPLIERDETAILS_Type", propOrder = {
    "languageid",
    "leadtimes"
})
public class RFQSUPPLIERDETAILS_Type {

    @XmlElement(name = "LANGUAGEID", required = true)
    protected LANGUAGEID_Type languageid;
    @XmlElement(name = "LEADTIMES")
    protected AMOUNT leadtimes;

    /**
     * Gets the value of the languageid property.
     * 
     * @return
     *     possible object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public LANGUAGEID_Type getLANGUAGEID() {
        return languageid;
    }

    /**
     * Sets the value of the languageid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public void setLANGUAGEID(LANGUAGEID_Type value) {
        this.languageid = value;
    }

    /**
     * Gets the value of the leadtimes property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getLEADTIMES() {
        return leadtimes;
    }

    /**
     * Sets the value of the leadtimes property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setLEADTIMES(AMOUNT value) {
        this.leadtimes = value;
    }

}
